package com.bonus.material.task.service;

import java.util.List;
import com.bonus.material.task.domain.TmTaskAgreement;

/**
 * 任务Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface ITmTaskAgreementService {
    /**
     * 查询任务
     * 
     * @param taskId 任务主键
     * @return 任务
     */
    public TmTaskAgreement selectTmTaskAgreementByTaskId(Long taskId);

    /**
     * 查询任务列表
     * 
     * @param tmTaskAgreement 任务
     * @return 任务集合
     */
    public List<TmTaskAgreement> selectTmTaskAgreementList(TmTaskAgreement tmTaskAgreement);

    /**
     * 新增任务
     * 
     * @param tmTaskAgreement 任务
     * @return 结果
     */
    public int insertTmTaskAgreement(TmTaskAgreement tmTaskAgreement);

    /**
     * 修改任务
     * 
     * @param tmTaskAgreement 任务
     * @return 结果
     */
    public int updateTmTaskAgreement(TmTaskAgreement tmTaskAgreement);

    /**
     * 批量删除任务
     * 
     * @param taskIds 需要删除的任务主键集合
     * @return 结果
     */
    public int deleteTmTaskAgreementByTaskIds(Long[] taskIds);

    /**
     * 删除任务信息
     * 
     * @param taskId 任务主键
     * @return 结果
     */
    public int deleteTmTaskAgreementByTaskId(Long taskId);
}
