package com.bonus.material.task.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.task.domain.TmTaskAgreement;
import com.bonus.material.task.service.ITmTaskAgreementService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 任务Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "任务接口")
@RestController
@RequestMapping("/tm_task_agreement")
public class TmTaskAgreementController extends BaseController {
    @Autowired
    private ITmTaskAgreementService tmTaskAgreementService;

    /**
     * 查询任务列表
     */
    @ApiOperation(value = "查询任务列表")
    @RequiresPermissions("task:agreement:list")
    @GetMapping("/list")
    public TableDataInfo list(TmTaskAgreement tmTaskAgreement) {
        startPage();
        List<TmTaskAgreement> list = tmTaskAgreementService.selectTmTaskAgreementList(tmTaskAgreement);
        return getDataTable(list);
    }

    /**
     * 导出任务列表
     */
    @ApiOperation(value = "导出任务列表")
    @PreventRepeatSubmit
    @RequiresPermissions("task:agreement:export")
    @SysLog(title = "任务", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出任务")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TmTaskAgreement tmTaskAgreement) {
        List<TmTaskAgreement> list = tmTaskAgreementService.selectTmTaskAgreementList(tmTaskAgreement);
        ExcelUtil<TmTaskAgreement> util = new ExcelUtil<TmTaskAgreement>(TmTaskAgreement.class);
        util.exportExcel(response, list, "任务数据");
    }

    /**
     * 获取任务详细信息
     */
    @ApiOperation(value = "获取任务详细信息")
    @RequiresPermissions("task:agreement:query")
    @GetMapping(value = "/{taskId}")
    public AjaxResult getInfo(@PathVariable("taskId") Long taskId) {
        return success(tmTaskAgreementService.selectTmTaskAgreementByTaskId(taskId));
    }

    /**
     * 新增任务
     */
    @ApiOperation(value = "新增任务")
    @PreventRepeatSubmit
    @RequiresPermissions("task:agreement:add")
    @SysLog(title = "任务", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增任务")
    @PostMapping
    public AjaxResult add(@RequestBody TmTaskAgreement tmTaskAgreement) {
        try {
            return toAjax(tmTaskAgreementService.insertTmTaskAgreement(tmTaskAgreement));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改任务
     */
    @ApiOperation(value = "修改任务")
    @PreventRepeatSubmit
    @RequiresPermissions("task:agreement:edit")
    @SysLog(title = "任务", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改任务")
    @PutMapping
    public AjaxResult edit(@RequestBody TmTaskAgreement tmTaskAgreement) {
        try {
            return toAjax(tmTaskAgreementService.updateTmTaskAgreement(tmTaskAgreement));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除任务
     */
    @ApiOperation(value = "删除任务")
    @PreventRepeatSubmit
    @RequiresPermissions("task:agreement:remove")
    @SysLog(title = "任务", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除任务")
	@DeleteMapping("/{taskIds}")
    public AjaxResult remove(@PathVariable Long[] taskIds) {
        return toAjax(tmTaskAgreementService.deleteTmTaskAgreementByTaskIds(taskIds));
    }
}
